@@ -1,7 +1,7 @@
 #!/bin/bash
 set -Eeuo pipefail
 
-bin/install_rust_latest.sh
+bin/install_rust.sh
 pip3 install -r bin/requirements-frozen.txt
-sudo apt update && sudo apt install -y libxml2-utils
+sudo apt-get update && sudo apt-get install -y libxml2-utils
 
