@@ -31,7 +31,7 @@ convert_toml_crates_to_key_value() {
 
     # convert toml crates to key value
     sed -n "/dependencies\]/,/^$/p" "${toml_file}" |
-        grep --extended-regexp --invert-match "^\[|path|^$" |
+        grep --extended-regexp --invert-match "^\[|path|^$|^#" |
             cut --delimiter ',' --field 1 |
                 sed "s/version//g" |
                     tr -d '"{=' |
@@ -47,7 +47,7 @@ get_crate_latest_version() {
     # get crate latest version
     crate_object=$(curl -kLs "${crate_url}" || true)
     crate_max_stable_version=$(echo "${crate_object}" | (jq -r .crate.max_stable_version 2>/dev/null || true))
-    last_version=$(echo "${crate_max_stable_version}" | (grep --extended-regexp "^[0-9].*.[0-9].*.[0-9]$" || true))
+    last_version=$(echo "${crate_max_stable_version}" | (grep --extended-regexp --only-matching "^[0-9]*\.[0-9]*\.[0-9]*" || true))
     echo "${last_version}"
 }
 
@@ -150,7 +150,7 @@ main() {
         echo -e "\n--------------------------------------------------------"
         echo -e "### Crates updates for *Cargo.lock*\n"
         cargo update --color always -vv 2>&1 |
-            (grep -Ev "crates.io index|Removing" || true) |
+            (grep -Ev "crates.io index|Removing|^#" || true) |
                 tr -s ' ' |
                     sed -r "s/\x1B\[([0-9]{1,3}(;[0-9]{1,2})?)?[mGK]//g" |
                         sed "s/ Updating //g" |
