@@ -1,11 +1,10 @@
 #!/usr/bin/env python3
 import glob
 import re
-
-import test_echo
 import test_lint
 import test_format
-import test_hurl
+import test_script
+import platform
 
 
 def get_files(glob_expr):
@@ -19,28 +18,22 @@ def accept(f: str) -> bool:
 
 def main():
     # Static run (without server)
-    [
-        test_echo.test(f)
-        for f in get_files("tests_ok/*.hurl")
-        + get_files("tests_failed/*.hurl")
-        + get_files("tests_error_lint/*.hurl")
-        if accept(f)
-    ]
     [test_format.test("json", f) for f in get_files("tests_ok/*.hurl")]
     [test_format.test("json", f) for f in get_files("tests_failed/*.hurl")]
     [test_format.test("html", f) for f in get_files("tests_ok/*.hurl")]
     [test_format.test("html", f) for f in get_files("tests_failed/*.hurl")]
     [test_lint.test(f) for f in get_files("tests_error_lint/*.hurl")]
-    [test_hurl.test(f) for f in get_files("tests_error_parser/*.hurl")]
 
-    # Dynamic run (with server)
-    [
-        test_hurl.test(f)
-        for f in get_files("tests_ok/*.hurl")
-        + get_files("tests_failed/*.hurl")
-        + get_files("ssl/*.hurl")
-        if accept(f)
-    ]
+    # Run test scripts
+    extension = "ps1" if platform.system() == "Windows" else "sh"
+    script_files = (
+        get_files("tests_ok/*." + extension)
+        + get_files("tests_failed/*." + extension)
+        + get_files("tests_error_parser/*." + extension)
+        + get_files("ssl/*." + extension)
+    )
+    for f in sorted(script_files):
+        test_script.test(f)
 
     print("test integration ok!")
 
