@@ -15,23 +15,21 @@
  * limitations under the License.
  *
  */
-
-use std::error::Error;
-
-pub use self::fs::read_to_string;
-pub use self::options::app;
-pub use self::options::output_color;
-pub use self::options::parse_options;
-pub use self::options::{CliOptions, OutputType};
-pub use self::variables::parse as parse_variable;
-pub use self::variables::parse_value as parse_variable_value;
-pub use crate::util::logger::{error_string_no_color, Logger};
-
 mod fs;
-pub mod interactive;
+mod interactive;
 mod options;
 mod variables;
-pub use self::options::{get_strings, has_flag};
+
+use std::error::Error;
+use std::fmt;
+
+use hurl::{output, report};
+
+pub use self::fs::read_to_string;
+pub use self::options::{
+    app, get_strings, has_flag, output_color, parse_options, CliOptions, OutputType,
+};
+pub use self::variables::{parse as parse_variable, parse_value as parse_variable_value};
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct CliError {
@@ -56,8 +54,24 @@ impl From<&str> for CliError {
 
 impl From<String> for CliError {
     fn from(e: String) -> Self {
-        Self {
-            message: format!("{e:?}"),
-        }
+        Self { message: e }
+    }
+}
+
+impl From<report::Error> for CliError {
+    fn from(e: report::Error) -> Self {
+        Self { message: e.message }
+    }
+}
+
+impl From<output::Error> for CliError {
+    fn from(e: output::Error) -> Self {
+        Self { message: e.message }
+    }
+}
+
+impl fmt::Display for CliError {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{}", self.message)
     }
 }
