@@ -15,9 +15,9 @@
  * limitations under the License.
  *
  */
-
 use core::fmt;
 
+/// Represents an HTTP header
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Header {
     pub name: String,
@@ -30,12 +30,16 @@ impl fmt::Display for Header {
     }
 }
 
-/// Returns all header values for given name
-///
-/// # Arguments
-///
-/// * `headers` - A list of HTTP headers
-/// * `name` - A name to filter header (case insensitively)
+impl Header {
+    pub fn new(name: &str, value: &str) -> Self {
+        Header {
+            name: name.to_string(),
+            value: value.to_string(),
+        }
+    }
+}
+
+/// Returns all `headers` values for given `name`.
 pub fn get_values(headers: &[Header], name: &str) -> Vec<String> {
     headers
         .iter()
