@@ -15,9 +15,8 @@
  * limitations under the License.
  *
  */
-
-use crate::cli::Logger;
 use crate::http::{debug, mimetype, Request};
+use crate::util::logger::Logger;
 
 impl Request {
     /// Log request body.
