@@ -653,11 +653,11 @@ fn test_cacert() {
     let certificate = response.certificate.unwrap();
 
     assert_eq!(
-        certificate.issuer,
+        certificate.issuer.replace(" = ", "=").replace(";", " "),
         "C=US, ST=Denial, L=Springfield, O=Dis, CN=localhost".to_string()
     );
     assert_eq!(
-        certificate.subject,
+        certificate.subject.replace(" = ", "=").replace(";", " "),
         "C=US, ST=Denial, L=Springfield, O=Dis, CN=localhost".to_string()
     );
     assert_eq!(
