@@ -15,18 +15,22 @@
  * limitations under the License.
  *
  */
-mod html;
-mod junit;
 
-pub use html::write_html_report;
-pub use junit::create_report as create_junit_report;
-pub use junit::Testcase;
-use std::path::Path;
+//! Various reports for Hurl runs (JUnit, HTML etc...) A report aggregates multiple runs into
+//! a single unit.
 
-/// Returns the canonical fullname relative to / (technically a relative path)
-/// The function will panic if the input file does not exist
-pub fn canonicalize_filename(input_file: &str) -> String {
-    let relative_input_file = Path::new(input_file).canonicalize().expect("existing file");
-    let relative_input_file = relative_input_file.to_string_lossy();
-    relative_input_file.trim_start_matches('/').to_string()
+use std::fmt;
+
+pub mod html;
+pub mod junit;
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct Error {
+    pub message: String,
+}
+
+impl fmt::Display for Error {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        write!(f, "{}", self.message)
+    }
 }
