@@ -17,10 +17,10 @@
  */
 use std::path::PathBuf;
 
-use crate::http;
 use hurl_core::ast::SourceInfo;
 
-use super::value::Value;
+use crate::http::{Call, Cookie};
+use crate::runner::value::Value;
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum Verbosity {
@@ -30,11 +30,10 @@ pub enum Verbosity {
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct HurlResult {
-    pub filename: String,
     pub entries: Vec<EntryResult>,
     pub time_in_ms: u128,
     pub success: bool,
-    pub cookies: Vec<http::Cookie>,
+    pub cookies: Vec<Cookie>,
 }
 
 impl HurlResult {
@@ -70,12 +69,6 @@ pub struct EntryResult {
     pub compressed: bool, // The entry has been executed with `--compressed` option
 }
 
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub struct Call {
-    pub request: http::Request,
-    pub response: http::Response,
-}
-
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum AssertResult {
     Version {
@@ -113,10 +106,6 @@ pub struct CaptureResult {
 
 pub type PredicateResult = Result<(), Error>;
 
-// endregion
-
-// region error
-
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Error {
     pub source_info: SourceInfo,
@@ -210,5 +199,3 @@ pub enum RunnerError {
     FilterInvalidInput(String),
     FilterRegexNoCapture {},
 }
-
-// endregion
