@@ -19,8 +19,8 @@ use std::collections::HashMap;
 
 use hurl_core::ast::Expr;
 
-use super::core::{Error, RunnerError};
-use super::value::Value;
+use crate::runner::core::{Error, RunnerError};
+use crate::runner::value::Value;
 
 /// Evaluates the expression `expr` with `variables` map and `http_response`, returns a
 /// [`Value`] on success or an [`Error`] .
