@@ -18,15 +18,13 @@
 use std::cmp::Ordering;
 use std::collections::HashMap;
 
+use hurl_core::ast::*;
 use regex;
 
-use hurl_core::ast::*;
-
-use super::core::Error;
-use super::template::eval_template;
-use super::value::Value;
-use crate::runner::core::PredicateResult;
+use crate::runner::core::{Error, PredicateResult};
 use crate::runner::predicate_value::eval_predicate_value;
+use crate::runner::template::eval_template;
+use crate::runner::value::Value;
 use crate::runner::RunnerError;
 
 pub fn eval_predicate(
@@ -94,6 +92,7 @@ impl Value {
     pub fn display(&self) -> String {
         match self {
             Value::Bool(v) => format!("bool <{v}>"),
+            Value::Date(v) => format!("date <{v}>"),
             Value::Integer(v) => format!("int <{v}>"),
             Value::String(v) => format!("string <{v}>"),
             Value::Float(f) => format!("float <{}>", format_float(*f)),
@@ -139,6 +138,7 @@ impl Value {
         match self {
             Value::Bool(value) => format!("bool <{value}>"),
             Value::Bytes(values) => format!("list of size {}", values.len()),
+            Value::Date(value) => format!("date <{value}>"),
             Value::Float(f) => format!("float <{}>", format_float(*f)),
             Value::Integer(value) => format!("integer <{value}>"),
             Value::List(value) => format!("list of size {}", value.len()),
@@ -230,6 +230,7 @@ fn expected(
         PredicateFuncValue::IsString {} => Ok("string".to_string()),
         PredicateFuncValue::IsCollection {} => Ok("collection".to_string()),
         PredicateFuncValue::Exist {} => Ok("something".to_string()),
+        PredicateFuncValue::IsEmpty {} => Ok("empty".to_string()),
     }
 }
 
@@ -495,6 +496,40 @@ fn eval_something(
                 type_mismatch: false,
             }),
         },
+
+        // empty
+        PredicateFuncValue::IsEmpty {} => match value {
+            Value::List(values) => Ok(AssertResult {
+                success: values.len() as i64 == 0,
+                actual: values.len().to_string(),
+                expected: 0.to_string(),
+                type_mismatch: false,
+            }),
+            Value::String(data) => Ok(AssertResult {
+                success: data.len() as i64 == 0,
+                actual: data.len().to_string(),
+                expected: 0.to_string(),
+                type_mismatch: false,
+            }),
+            Value::Nodeset(nodeset) => Ok(AssertResult {
+                success: *nodeset as i64 == 0,
+                actual: nodeset.to_string(),
+                expected: 0.to_string(),
+                type_mismatch: false,
+            }),
+            Value::Bytes(data) => Ok(AssertResult {
+                success: data.len() as i64 == 0,
+                actual: data.len().to_string(),
+                expected: 0.to_string(),
+                type_mismatch: false,
+            }),
+            _ => Ok(AssertResult {
+                success: false,
+                actual: value.display(),
+                expected: "count equals to 0".to_string(),
+                type_mismatch: true,
+            }),
+        },
         _ => panic!(),
     }
 }
@@ -827,8 +862,7 @@ fn contains(haystack: &[u8], needle: &[u8]) -> bool {
 
 #[cfg(test)]
 mod tests {
-    use super::AssertResult;
-    use super::*;
+    use super::{AssertResult, *};
 
     fn whitespace() -> Whitespace {
         Whitespace {
@@ -1464,6 +1498,44 @@ mod tests {
         assert_eq!(assert_result.expected.as_str(), "1");
     }
 
+    #[test]
+    fn test_predicate_is_empty_are_false() {
+        let variables = HashMap::new();
+        let assert_result = eval_something(
+            &PredicateFunc {
+                value: PredicateFuncValue::IsEmpty {},
+                source_info: SourceInfo::new(0, 0, 0, 0),
+            },
+            &variables,
+            &Value::List(vec![Value::Integer(1)]),
+        )
+        .unwrap();
+
+        assert!(!assert_result.success);
+        assert!(!assert_result.type_mismatch);
+        assert_eq!(assert_result.actual.as_str(), "1");
+        assert_eq!(assert_result.expected.as_str(), "0");
+    }
+
+    #[test]
+    fn test_predicate_is_empty_are_true() {
+        let variables = HashMap::new();
+        let assert_result = eval_something(
+            &PredicateFunc {
+                value: PredicateFuncValue::IsEmpty {},
+                source_info: SourceInfo::new(0, 0, 0, 0),
+            },
+            &variables,
+            &Value::List(vec![]),
+        )
+        .unwrap();
+
+        assert!(assert_result.success);
+        assert!(!assert_result.type_mismatch);
+        assert_eq!(assert_result.actual.as_str(), "0");
+        assert_eq!(assert_result.expected.as_str(), "0");
+    }
+
     #[test]
     fn test_predicate_count_equals() {
         let variables = HashMap::new();
