@@ -15,251 +15,344 @@
  * limitations under the License.
  *
  */
-
-use regex::Regex;
 use std::collections::HashMap;
 
-use super::core::{Error, RunnerError};
-use super::template::eval_template;
-use super::value::Value;
-use super::xpath;
-use crate::http;
-use crate::jsonpath;
 use hurl_core::ast::*;
+use regex::Regex;
 use sha2::Digest;
 
+use crate::runner::core::{Error, RunnerError};
+use crate::runner::template::eval_template;
+use crate::runner::value::Value;
+use crate::runner::xpath;
+use crate::{http, jsonpath};
+
 pub type QueryResult = Result<Option<Value>, Error>;
 
+/// Evaluates this `query` and returns a [`QueryResult`], using the HTTP response `http_response` and `variables`.
 pub fn eval_query(
     query: &Query,
     variables: &HashMap<String, Value>,
     http_response: &http::Response,
 ) -> QueryResult {
     match query.value.clone() {
-        QueryValue::Status {} => Ok(Some(Value::Integer(i64::from(http_response.status)))),
-        QueryValue::Url {} => Ok(Some(Value::String(http_response.url.clone()))),
-        QueryValue::Header { name, .. } => {
-            let header_name = eval_template(&name, variables)?;
-            let values = http_response.get_header_values(&header_name);
-            if values.is_empty() {
-                Ok(None)
-            } else if values.len() == 1 {
-                let value = values.first().unwrap().to_string();
-                Ok(Some(Value::String(value)))
-            } else {
-                let values = values
-                    .iter()
-                    .map(|v| Value::String(v.to_string()))
-                    .collect();
-                Ok(Some(Value::List(values)))
-            }
-        }
+        QueryValue::Status {} => eval_query_status(http_response),
+        QueryValue::Url {} => eval_query_url(http_response),
+        QueryValue::Header { name, .. } => eval_query_header(http_response, &name, variables),
         QueryValue::Cookie {
             expr: CookiePath { name, attribute },
             ..
-        } => {
-            let cookie_name = eval_template(&name, variables)?;
-            match http_response.get_cookie(cookie_name) {
-                None => Ok(None),
-                Some(cookie) => {
-                    let attribute_name = if let Some(attribute) = attribute {
-                        attribute.name
-                    } else {
-                        CookieAttributeName::Value("Value".to_string())
-                    };
-                    Ok(eval_cookie_attribute_name(attribute_name, cookie))
-                }
-            }
-        }
-        QueryValue::Body {} => {
-            // can return a string if encoding is known and utf8
-            match http_response.text() {
-                Ok(s) => Ok(Some(Value::String(s))),
-                Err(inner) => Err(Error {
-                    source_info: query.source_info.clone(),
-                    inner: RunnerError::from(inner),
-                    assert: false,
-                }),
-            }
-        }
+        } => eval_query_cookie(http_response, &name, &attribute, variables),
+        QueryValue::Body {} => eval_query_body(http_response, &query.source_info),
         QueryValue::Xpath { expr, .. } => {
-            let source_info = &expr.source_info;
-            let value = eval_template(&expr, variables)?;
-            match http_response.text() {
-                Err(inner) => Err(Error {
-                    source_info: query.source_info.clone(),
-                    inner: RunnerError::from(inner),
-                    assert: false,
-                }),
-                Ok(xml) => {
-                    let result = if http_response.is_html() {
-                        xpath::eval_html(&xml, &value)
-                    } else {
-                        xpath::eval_xml(&xml, &value)
-                    };
-                    match result {
-                        Ok(value) => Ok(Some(value)),
-                        Err(xpath::XpathError::InvalidXml {}) => Err(Error {
-                            source_info: query.source_info.clone(),
-                            inner: RunnerError::QueryInvalidXml,
-                            assert: false,
-                        }),
-                        Err(xpath::XpathError::InvalidHtml {}) => Err(Error {
-                            source_info: query.source_info.clone(),
-                            inner: RunnerError::QueryInvalidXml,
-                            assert: false,
-                        }),
-                        Err(xpath::XpathError::Eval {}) => Err(Error {
-                            source_info: source_info.clone(),
-                            inner: RunnerError::QueryInvalidXpathEval,
-                            assert: false,
-                        }),
-                        Err(xpath::XpathError::Unsupported {}) => {
-                            panic!("Unsupported xpath {value}"); // good usecase for panic - I could nmot reporduce this usecase myself
-                        }
-                    }
-                }
-            }
+            eval_query_xpath(http_response, &expr, variables, &query.source_info)
         }
         QueryValue::Jsonpath { expr, .. } => {
-            let value = eval_template(&expr, variables)?;
-            let source_info = expr.source_info;
-            let jsonpath_query = match jsonpath::parse(value.as_str()) {
-                Ok(q) => q,
-                Err(_) => {
-                    return Err(Error {
-                        source_info,
-                        inner: RunnerError::QueryInvalidJsonpathExpression { value },
-                        assert: false,
-                    });
-                }
-            };
-            let json = match http_response.text() {
-                Err(inner) => {
-                    return Err(Error {
-                        source_info: query.source_info.clone(),
-                        inner: RunnerError::from(inner),
-                        assert: false,
-                    });
-                }
-                Ok(v) => v,
-            };
-            let value = match serde_json::from_str(json.as_str()) {
-                Err(_) => {
-                    return Err(Error {
-                        source_info: query.source_info.clone(),
-                        inner: RunnerError::QueryInvalidJson,
-                        assert: false,
-                    });
-                }
-                Ok(v) => v,
-            };
-            let results = jsonpath_query.eval(value);
-            if results.is_empty() {
-                Ok(None)
-            } else if results.len() == 1 {
-                // list coercions
-                Ok(Some(Value::from_json(results.get(0).unwrap())))
-            } else {
-                Ok(Some(Value::from_json(&serde_json::Value::Array(results))))
-            }
+            eval_query_jsonpath(http_response, &expr, variables, &query.source_info)
         }
         QueryValue::Regex { value, .. } => {
-            let s = match http_response.text() {
-                Err(inner) => {
-                    return Err(Error {
-                        source_info: query.source_info.clone(),
-                        inner: RunnerError::from(inner),
-                        assert: false,
-                    });
-                }
-                Ok(v) => v,
-            };
-            let re = match value {
-                RegexValue::Template(t) => {
-                    let value = eval_template(&t, variables)?;
-                    match Regex::new(value.as_str()) {
-                        Ok(re) => re,
-                        Err(_) => {
-                            let source_info = t.source_info;
-                            return Err(Error {
-                                source_info,
-                                inner: RunnerError::InvalidRegex(),
-                                assert: false,
-                            });
-                        }
-                    }
-                }
-                RegexValue::Regex(re) => re.inner,
-            };
-            match re.captures(s.as_str()) {
-                Some(captures) => match captures.get(1) {
-                    Some(v) => Ok(Some(Value::String(v.as_str().to_string()))),
-                    None => Ok(None),
-                },
-                None => Ok(None),
-            }
+            eval_query_regex(http_response, &value, variables, &query.source_info)
         }
-        QueryValue::Variable { name, .. } => {
-            let name = eval_template(&name, variables)?;
-            if let Some(value) = variables.get(name.as_str()) {
-                Ok(Some(value.clone()))
+        QueryValue::Variable { name, .. } => eval_query_variable(&name, variables),
+        QueryValue::Duration {} => eval_query_duration(http_response),
+        QueryValue::Bytes {} => eval_query_bytes(http_response, &query.source_info),
+        QueryValue::Sha256 {} => eval_query_sha256(http_response, &query.source_info),
+        QueryValue::Md5 {} => eval_query_md5(http_response, &query.source_info),
+        QueryValue::Certificate {
+            attribute_name: field,
+            ..
+        } => eval_query_certificate(http_response, field),
+    }
+}
+
+fn eval_query_status(response: &http::Response) -> QueryResult {
+    Ok(Some(Value::Integer(i64::from(response.status))))
+}
+
+fn eval_query_url(response: &http::Response) -> QueryResult {
+    Ok(Some(Value::String(response.url.clone())))
+}
+
+fn eval_query_header(
+    response: &http::Response,
+    header: &Template,
+    variables: &HashMap<String, Value>,
+) -> QueryResult {
+    let header = eval_template(header, variables)?;
+    let values = response.get_header_values(&header);
+    if values.is_empty() {
+        Ok(None)
+    } else if values.len() == 1 {
+        let value = values.first().unwrap().to_string();
+        Ok(Some(Value::String(value)))
+    } else {
+        let values = values
+            .iter()
+            .map(|v| Value::String(v.to_string()))
+            .collect();
+        Ok(Some(Value::List(values)))
+    }
+}
+
+fn eval_query_cookie(
+    response: &http::Response,
+    name: &Template,
+    attribute: &Option<CookieAttribute>,
+    variables: &HashMap<String, Value>,
+) -> QueryResult {
+    let name = eval_template(name, variables)?;
+    match response.get_cookie(name) {
+        None => Ok(None),
+        Some(cookie) => {
+            let attribute_name = if let Some(attribute) = attribute {
+                attribute.name.clone()
             } else {
-                Ok(None)
-            }
-        }
-        QueryValue::Duration {} => Ok(Some(Value::Integer(
-            http_response.duration.as_millis() as i64
-        ))),
-        QueryValue::Bytes {} => match http_response.uncompress_body() {
-            Ok(s) => Ok(Some(Value::Bytes(s))),
-            Err(inner) => Err(Error {
-                source_info: query.source_info.clone(),
-                inner: RunnerError::from(inner),
-                assert: false,
-            }),
-        },
-        QueryValue::Sha256 {} => {
-            let bytes = match http_response.uncompress_body() {
-                Ok(s) => s,
-                Err(inner) => {
-                    return Err(Error {
-                        source_info: query.source_info.clone(),
-                        inner: RunnerError::from(inner),
-                        assert: false,
-                    })
-                }
+                CookieAttributeName::Value("Value".to_string())
             };
-            let mut hasher = sha2::Sha256::new();
-            hasher.update(bytes);
-            let result = hasher.finalize();
-            let bytes = Value::Bytes(result[..].to_vec());
-            Ok(Some(bytes))
-        }
-        QueryValue::Md5 {} => {
-            let bytes = match http_response.uncompress_body() {
-                Ok(s) => s,
-                Err(inner) => {
-                    return Err(Error {
-                        source_info: query.source_info.clone(),
-                        inner: RunnerError::from(inner),
-                        assert: false,
-                    })
-                }
-            };
-            let bytes = md5::compute(bytes).to_vec();
-            Ok(Some(Value::Bytes(bytes)))
+            Ok(eval_cookie_attribute_name(attribute_name, cookie))
         }
     }
 }
 
-pub fn eval_cookie_attribute_name(
+fn eval_query_body(response: &http::Response, query_source_info: &SourceInfo) -> QueryResult {
+    // Can return a string if encoding is known and utf8.
+    match response.text() {
+        Ok(s) => Ok(Some(Value::String(s))),
+        Err(inner) => Err(Error {
+            source_info: query_source_info.clone(),
+            inner: RunnerError::from(inner),
+            assert: false,
+        }),
+    }
+}
+
+fn eval_query_xpath(
+    response: &http::Response,
+    expr: &Template,
+    variables: &HashMap<String, Value>,
+    query_source_info: &SourceInfo,
+) -> QueryResult {
+    let expr_source_info = &expr.source_info;
+    let value = eval_template(expr, variables)?;
+    match response.text() {
+        Err(inner) => Err(Error {
+            source_info: query_source_info.clone(),
+            inner: RunnerError::from(inner),
+            assert: false,
+        }),
+        Ok(xml) => {
+            let result = if response.is_html() {
+                xpath::eval_html(&xml, &value)
+            } else {
+                xpath::eval_xml(&xml, &value)
+            };
+            match result {
+                Ok(value) => Ok(Some(value)),
+                Err(xpath::XpathError::InvalidXml {}) => Err(Error {
+                    source_info: query_source_info.clone(),
+                    inner: RunnerError::QueryInvalidXml,
+                    assert: false,
+                }),
+                Err(xpath::XpathError::InvalidHtml {}) => Err(Error {
+                    source_info: query_source_info.clone(),
+                    inner: RunnerError::QueryInvalidXml,
+                    assert: false,
+                }),
+                Err(xpath::XpathError::Eval {}) => Err(Error {
+                    source_info: expr_source_info.clone(),
+                    inner: RunnerError::QueryInvalidXpathEval,
+                    assert: false,
+                }),
+                Err(xpath::XpathError::Unsupported {}) => {
+                    panic!("Unsupported xpath {value}"); // good usecase for panic - I could nmot reporduce this usecase myself
+                }
+            }
+        }
+    }
+}
+
+fn eval_query_jsonpath(
+    response: &http::Response,
+    expr: &Template,
+    variables: &HashMap<String, Value>,
+    query_source_info: &SourceInfo,
+) -> QueryResult {
+    let value = eval_template(expr, variables)?;
+    let expr_source_info = &expr.source_info;
+    let jsonpath_query = match jsonpath::parse(value.as_str()) {
+        Ok(q) => q,
+        Err(_) => {
+            return Err(Error {
+                source_info: expr_source_info.clone(),
+                inner: RunnerError::QueryInvalidJsonpathExpression { value },
+                assert: false,
+            });
+        }
+    };
+    let json = match response.text() {
+        Err(inner) => {
+            return Err(Error {
+                source_info: query_source_info.clone(),
+                inner: RunnerError::from(inner),
+                assert: false,
+            });
+        }
+        Ok(v) => v,
+    };
+    let value = match serde_json::from_str(json.as_str()) {
+        Err(_) => {
+            return Err(Error {
+                source_info: query_source_info.clone(),
+                inner: RunnerError::QueryInvalidJson,
+                assert: false,
+            });
+        }
+        Ok(v) => v,
+    };
+    let results = jsonpath_query.eval(&value);
+    if results.is_empty() {
+        Ok(None)
+    } else if results.len() == 1 {
+        // All results from JSONPath queries return an array <https://goessner.net/articles/JsonPath/>.
+        // For usability, we coerce lists that have only one element to this element.
+        Ok(Some(Value::from_json(results.get(0).unwrap())))
+    } else {
+        Ok(Some(Value::from_json(&serde_json::Value::Array(results))))
+    }
+}
+
+fn eval_query_regex(
+    response: &http::Response,
+    regex: &RegexValue,
+    variables: &HashMap<String, Value>,
+    query_source_info: &SourceInfo,
+) -> QueryResult {
+    let s = match response.text() {
+        Err(inner) => {
+            return Err(Error {
+                source_info: query_source_info.clone(),
+                inner: RunnerError::from(inner),
+                assert: false,
+            });
+        }
+        Ok(v) => v,
+    };
+    let re = match regex {
+        RegexValue::Template(t) => {
+            let value = eval_template(t, variables)?;
+            match Regex::new(value.as_str()) {
+                Ok(re) => re,
+                Err(_) => {
+                    let source_info = t.source_info.clone();
+                    return Err(Error {
+                        source_info,
+                        inner: RunnerError::InvalidRegex(),
+                        assert: false,
+                    });
+                }
+            }
+        }
+        RegexValue::Regex(re) => re.inner.clone(),
+    };
+    match re.captures(s.as_str()) {
+        Some(captures) => match captures.get(1) {
+            Some(v) => Ok(Some(Value::String(v.as_str().to_string()))),
+            None => Ok(None),
+        },
+        None => Ok(None),
+    }
+}
+
+fn eval_query_variable(name: &Template, variables: &HashMap<String, Value>) -> QueryResult {
+    let name = eval_template(name, variables)?;
+    if let Some(value) = variables.get(name.as_str()) {
+        Ok(Some(value.clone()))
+    } else {
+        Ok(None)
+    }
+}
+
+fn eval_query_duration(response: &http::Response) -> QueryResult {
+    Ok(Some(Value::Integer(response.duration.as_millis() as i64)))
+}
+
+fn eval_query_bytes(response: &http::Response, query_source_info: &SourceInfo) -> QueryResult {
+    match response.uncompress_body() {
+        Ok(s) => Ok(Some(Value::Bytes(s))),
+        Err(inner) => Err(Error {
+            source_info: query_source_info.clone(),
+            inner: RunnerError::from(inner),
+            assert: false,
+        }),
+    }
+}
+
+fn eval_query_sha256(response: &http::Response, query_source_info: &SourceInfo) -> QueryResult {
+    let bytes = match response.uncompress_body() {
+        Ok(s) => s,
+        Err(inner) => {
+            return Err(Error {
+                source_info: query_source_info.clone(),
+                inner: RunnerError::from(inner),
+                assert: false,
+            })
+        }
+    };
+    let mut hasher = sha2::Sha256::new();
+    hasher.update(bytes);
+    let result = hasher.finalize();
+    let bytes = Value::Bytes(result[..].to_vec());
+    Ok(Some(bytes))
+}
+
+fn eval_query_md5(response: &http::Response, query_source_info: &SourceInfo) -> QueryResult {
+    let bytes = match response.uncompress_body() {
+        Ok(s) => s,
+        Err(inner) => {
+            return Err(Error {
+                source_info: query_source_info.clone(),
+                inner: RunnerError::from(inner),
+                assert: false,
+            })
+        }
+    };
+    let bytes = md5::compute(bytes).to_vec();
+    Ok(Some(Value::Bytes(bytes)))
+}
+
+fn eval_query_certificate(
+    response: &http::Response,
+    certificate_attribute: CertificateAttributeName,
+) -> QueryResult {
+    if let Some(certificate) = &response.certificate {
+        let value = match certificate_attribute {
+            CertificateAttributeName::Subject => Value::String(certificate.subject.clone()),
+            CertificateAttributeName::Issuer => Value::String(certificate.issuer.clone()),
+            CertificateAttributeName::StartDate => Value::Date(certificate.start_date),
+            CertificateAttributeName::ExpireDate => Value::Date(certificate.expire_date),
+            CertificateAttributeName::SerialNumber => {
+                Value::String(certificate.serial_number.clone())
+            }
+        };
+        Ok(Some(value))
+    } else {
+        Ok(None)
+    }
+}
+
+fn eval_cookie_attribute_name(
     cookie_attribute_name: CookieAttributeName,
     cookie: http::ResponseCookie,
 ) -> Option<Value> {
     match cookie_attribute_name {
         CookieAttributeName::Value(_) => Some(Value::String(cookie.value)),
-        CookieAttributeName::Expires(_) => cookie.expires().map(Value::String),
+        CookieAttributeName::Expires(_) => {
+            let s = cookie.expires().unwrap();
+            match chrono::DateTime::parse_from_rfc2822(s.as_str()) {
+                Ok(v) => Some(Value::Date(v.with_timezone(&chrono::Utc))),
+                Err(_) => todo!(),
+            }
+        }
         CookieAttributeName::MaxAge(_) => cookie.max_age().map(Value::Integer),
         CookieAttributeName::Domain(_) => cookie.domain().map(Value::String),
         CookieAttributeName::Path(_) => cookie.path().map(Value::String),
@@ -311,10 +404,12 @@ impl Value {
 
 #[cfg(test)]
 pub mod tests {
-    use super::*;
     use hex_literal::hex;
+
     use hurl_core::ast::{Pos, SourceInfo};
 
+    use super::*;
+
     pub fn xpath_invalid_query() -> Query {
         // xpath ???
         let whitespace = Whitespace {
@@ -379,28 +474,6 @@ pub mod tests {
         }
     }
 
-    pub fn json_http_response() -> http::Response {
-        http::Response {
-            version: http::Version::Http10,
-            status: 0,
-            headers: vec![],
-            body: String::into_bytes(
-                r#"
-{
-  "success":false,
-  "errors": [
-    { "id": "error1"},
-    {"id": "error2"}
-  ]
-}
-"#
-                .to_string(),
-            ),
-            duration: Default::default(),
-            url: "".to_string(),
-        }
-    }
-
     pub fn jsonpath_success() -> Query {
         // jsonpath $.success
         Query {
@@ -591,17 +664,10 @@ pub mod tests {
             source_info: SourceInfo::new(0, 0, 0, 0),
         };
         let response = http::Response {
-            version: http::Version::Http10,
-            status: 0,
             headers: vec![
-                http::Header {
-                    name: "Set-Cookie".to_string(),
-                    value: "LSID=DQAAAKEaem_vYg; Path=/accounts; Expires=Wed, 13 Jan 2021 22:23:01 GMT; Secure; HttpOnly".to_string(),
-                }
+                http::Header::new("Set-Cookie", "LSID=DQAAAKEaem_vYg; Path=/accounts; Expires=Wed, 13 Jan 2021 22:23:01 GMT; Secure; HttpOnly")
             ],
-            body: vec![],
-            duration: Default::default(),
-            url: "".to_string(),
+            ..Default::default()
         };
 
         // cookie "LSID"
@@ -760,7 +826,11 @@ pub mod tests {
                 cookie.clone(),
             )
             .unwrap(),
-            Value::String("Wed, 13 Jan 2021 22:23:01 GMT".to_string())
+            Value::Date(
+                chrono::DateTime::parse_from_rfc2822("Wed, 13 Jan 2021 22:23:01 GMT")
+                    .unwrap()
+                    .with_timezone(&chrono::Utc)
+            ),
         );
         assert_eq!(
             eval_cookie_attribute_name(
@@ -823,12 +893,8 @@ pub mod tests {
     fn test_query_invalid_utf8() {
         let variables = HashMap::new();
         let http_response = http::Response {
-            version: http::Version::Http10,
-            status: 0,
-            headers: vec![],
             body: vec![200],
-            duration: Default::default(),
-            url: "".to_string(),
+            ..Default::default()
         };
         let error = eval_query(&xpath_users(), &variables, &http_response)
             .err()
@@ -957,7 +1023,7 @@ pub mod tests {
             },
         };
 
-        let error = eval_query(&jsonpath_query, &variables, &json_http_response())
+        let error = eval_query(&jsonpath_query, &variables, &http::json_http_response())
             .err()
             .unwrap();
         assert_eq!(
@@ -979,12 +1045,8 @@ pub mod tests {
     fn test_query_invalid_json() {
         let variables = HashMap::new();
         let http_response = http::Response {
-            version: http::Version::Http10,
-            status: 0,
-            headers: vec![],
             body: String::into_bytes(String::from("xxx")),
-            duration: Default::default(),
-            url: "".to_string(),
+            ..Default::default()
         };
         let error = eval_query(&jsonpath_success(), &variables, &http_response)
             .err()
@@ -997,12 +1059,8 @@ pub mod tests {
     fn test_query_json_not_found() {
         let variables = HashMap::new();
         let http_response = http::Response {
-            version: http::Version::Http10,
-            status: 0,
-            headers: vec![],
             body: String::into_bytes(String::from("{}")),
-            duration: Default::default(),
-            url: "".to_string(),
+            ..Default::default()
         };
         //assert_eq!(jsonpath_success().eval(http_response).unwrap(), Value::List(vec![]));
         assert_eq!(
@@ -1015,13 +1073,13 @@ pub mod tests {
     fn test_query_json() {
         let variables = HashMap::new();
         assert_eq!(
-            eval_query(&jsonpath_success(), &variables, &json_http_response())
+            eval_query(&jsonpath_success(), &variables, &http::json_http_response())
                 .unwrap()
                 .unwrap(),
             Value::Bool(false)
         );
         assert_eq!(
-            eval_query(&jsonpath_errors(), &variables, &json_http_response())
+            eval_query(&jsonpath_errors(), &variables, &http::json_http_response())
                 .unwrap()
                 .unwrap(),
             Value::List(vec![
@@ -1083,12 +1141,8 @@ pub mod tests {
                 },
                 &variables,
                 &http::Response {
-                    version: http::Version::Http10,
-                    status: 200,
-                    headers: vec![],
                     body: vec![0xff],
-                    duration: Default::default(),
-                    url: "".to_string()
+                    ..Default::default()
                 }
             )
             .unwrap()
@@ -1098,4 +1152,34 @@ pub mod tests {
             )
         );
     }
+
+    #[test]
+    fn test_query_certificate() {
+        assert!(eval_query_certificate(
+            &http::Response {
+                ..Default::default()
+            },
+            CertificateAttributeName::Subject
+        )
+        .unwrap()
+        .is_none());
+        assert_eq!(
+            eval_query_certificate(
+                &http::Response {
+                    certificate: Some(http::Certificate {
+                        subject: "A=B, C=D".to_string(),
+                        issuer: "".to_string(),
+                        start_date: Default::default(),
+                        expire_date: Default::default(),
+                        serial_number: "".to_string()
+                    }),
+                    ..Default::default()
+                },
+                CertificateAttributeName::Subject
+            )
+            .unwrap()
+            .unwrap(),
+            Value::String("A=B, C=D".to_string())
+        );
+    }
 }
