@@ -15,7 +15,5 @@
  * limitations under the License.
  *
  */
-pub use self::path::is_descendant;
-
 pub mod logger;
-mod path;
+pub mod path;
