@@ -15,9 +15,10 @@
  * limitations under the License.
  *
  */
-use super::core::*;
 use core::fmt;
 
+use crate::ast::core::*;
+
 impl fmt::Display for Method {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         let s = match self {
@@ -232,6 +233,7 @@ impl PredicateFuncValue {
             PredicateFuncValue::IsString { .. } => "isString".to_string(),
             PredicateFuncValue::IsCollection { .. } => "isCollection".to_string(),
             PredicateFuncValue::Exist { .. } => "exists".to_string(),
+            PredicateFuncValue::IsEmpty { .. } => "isEmpty".to_string(),
         }
     }
 }
