@@ -15,23 +15,22 @@
  * limitations under the License.
  *
  */
-use crate::ast::HurlFile;
-
 pub type ParseResult<'a, T> = Result<T, Error>;
 pub type ParseFunc<'a, T> = fn(&mut Reader) -> ParseResult<'a, T>;
 
 pub fn parse_hurl_file(s: &str) -> ParseResult<'static, HurlFile> {
-    let mut reader = Reader::init(s);
+    let mut reader = Reader::new(s);
     parsers::hurl_file(&mut reader)
 }
 
 pub use self::error::{Error, ParseError};
-pub use self::json::boolean_value as parse_json_boolean;
-pub use self::json::null_value as parse_json_null;
-pub use self::json::number_value as parse_json_number;
-pub use self::json::parse as parse_json;
+pub use self::json::{
+    boolean_value as parse_json_boolean, null_value as parse_json_null,
+    number_value as parse_json_number, parse as parse_json,
+};
 pub use self::reader::Reader;
 pub use self::template::templatize;
+use crate::ast::HurlFile;
 
 mod base64;
 mod bytes;
