@@ -16,14 +16,12 @@
  *
  */
 use crate::ast::*;
-use crate::parser::{Error, ParseError};
-
-use super::combinators::*;
-use super::cookiepath::cookiepath;
-use super::primitives::*;
-use super::reader::Reader;
-use super::string::*;
-use super::ParseResult;
+use crate::parser::combinators::*;
+use crate::parser::cookiepath::cookiepath;
+use crate::parser::primitives::*;
+use crate::parser::reader::Reader;
+use crate::parser::string::*;
+use crate::parser::{Error, ParseError, ParseResult};
 
 pub fn query(reader: &mut Reader) -> ParseResult<'static, Query> {
     let start = reader.state.pos.clone();
@@ -51,6 +49,7 @@ fn query_value(reader: &mut Reader) -> ParseResult<'static, QueryValue> {
             bytes_query,
             sha256_query,
             md5_query,
+            certificate_query,
         ],
         reader,
     )
@@ -81,7 +80,7 @@ fn cookie_query(reader: &mut Reader) -> ParseResult<'static, QueryValue> {
     // todo should work with an encodedString in order to support escape sequence
     // or decode escape sequence with the cookiepath parser
 
-    let mut cookiepath_reader = Reader::init(s.as_str());
+    let mut cookiepath_reader = Reader::new(s.as_str());
     cookiepath_reader.state.pos = Pos {
         line: start.line,
         column: start.column + 1,
@@ -181,6 +180,41 @@ fn md5_query(reader: &mut Reader) -> ParseResult<'static, QueryValue> {
     Ok(QueryValue::Md5 {})
 }
 
+fn certificate_query(reader: &mut Reader) -> ParseResult<'static, QueryValue> {
+    try_literal("certificate", reader)?;
+    let space0 = one_or_more_spaces(reader)?;
+    let field = certificate_field(reader)?;
+    Ok(QueryValue::Certificate {
+        space0,
+        attribute_name: field,
+    })
+}
+
+fn certificate_field(reader: &mut Reader) -> ParseResult<'static, CertificateAttributeName> {
+    literal("\"", reader)?;
+    if try_literal(r#"Subject""#, reader).is_ok() {
+        Ok(CertificateAttributeName::Subject)
+    } else if try_literal(r#"Issuer""#, reader).is_ok() {
+        Ok(CertificateAttributeName::Issuer)
+    } else if try_literal(r#"Start-Date""#, reader).is_ok() {
+        Ok(CertificateAttributeName::StartDate)
+    } else if try_literal(r#"Expire-Date""#, reader).is_ok() {
+        Ok(CertificateAttributeName::ExpireDate)
+    } else if try_literal(r#"Serial-Number""#, reader).is_ok() {
+        Ok(CertificateAttributeName::SerialNumber)
+    } else {
+        let value =
+            "Field <Subject>, <Issuer>,<Start-Date>, <Expire-Date> or <Serial-Number>".to_string();
+        let inner = ParseError::Expecting { value };
+        let pos = reader.state.pos.clone();
+        Err(Error {
+            pos,
+            recoverable: false,
+            inner,
+        })
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -188,7 +222,7 @@ mod tests {
 
     #[test]
     fn test_query() {
-        let mut reader = Reader::init("status");
+        let mut reader = Reader::new("status");
         assert_eq!(
             query(&mut reader).unwrap(),
             Query {
@@ -200,7 +234,7 @@ mod tests {
 
     #[test]
     fn test_status_query() {
-        let mut reader = Reader::init("status");
+        let mut reader = Reader::new("status");
         assert_eq!(
             query(&mut reader).unwrap(),
             Query {
@@ -212,7 +246,7 @@ mod tests {
 
     #[test]
     fn test_header_query() {
-        let mut reader = Reader::init("header \"Foo\"");
+        let mut reader = Reader::new("header \"Foo\"");
         assert_eq!(
             header_query(&mut reader).unwrap(),
             QueryValue::Header {
@@ -234,7 +268,7 @@ mod tests {
 
     #[test]
     fn test_cookie_query() {
-        let mut reader = Reader::init("cookie \"Foo[Domain]\"");
+        let mut reader = Reader::new("cookie \"Foo[Domain]\"");
         assert_eq!(
             cookie_query(&mut reader).unwrap(),
             QueryValue::Cookie {
@@ -273,7 +307,7 @@ mod tests {
 
     #[test]
     fn test_xpath_query() {
-        let mut reader = Reader::init("xpath \"normalize-space(//head/title)\"");
+        let mut reader = Reader::new("xpath \"normalize-space(//head/title)\"");
         assert_eq!(
             xpath_query(&mut reader).unwrap(),
             QueryValue::Xpath {
@@ -292,7 +326,7 @@ mod tests {
             },
         );
 
-        let mut reader = Reader::init("xpath \"normalize-space(//div[contains(concat(' ',normalize-space(@class),' '),' monthly-price ')])\"");
+        let mut reader = Reader::new("xpath \"normalize-space(//div[contains(concat(' ',normalize-space(@class),' '),' monthly-price ')])\"");
         assert_eq!(xpath_query(&mut reader).unwrap(), QueryValue::Xpath {
             space0: Whitespace { value: String::from(" "), source_info: SourceInfo::new(1, 6, 1, 7) },
             expr: Template {
@@ -311,7 +345,7 @@ mod tests {
 
     #[test]
     fn test_jsonpath_query() {
-        let mut reader = Reader::init("jsonpath \"$['statusCode']\"");
+        let mut reader = Reader::new("jsonpath \"$['statusCode']\"");
         assert_eq!(
             jsonpath_query(&mut reader).unwrap(),
             QueryValue::Jsonpath {
@@ -329,7 +363,7 @@ mod tests {
                 },
             },
         );
-        let mut reader = Reader::init("jsonpath \"$.success\"");
+        let mut reader = Reader::new("jsonpath \"$.success\"");
         assert_eq!(
             jsonpath_query(&mut reader).unwrap(),
             QueryValue::Jsonpath {
@@ -351,7 +385,7 @@ mod tests {
 
     #[test]
     fn test_query_with_filters() {
-        let mut reader = Reader::init("body urlDecode ");
+        let mut reader = Reader::new("body urlDecode ");
         assert_eq!(
             query(&mut reader).unwrap(),
             Query {
