@@ -15,15 +15,13 @@
  * limitations under the License.
  *
  */
-
 use base64::engine::general_purpose;
 use base64::Engine;
-
 use hurl_core::ast::*;
 
 use super::serialize_json::*;
 
-pub fn format(hurl_file: HurlFile) -> String {
+pub fn format(hurl_file: &HurlFile) -> String {
     hurl_file.to_json().format()
 }
 
@@ -348,6 +346,16 @@ fn query_value_attributes(query_value: &QueryValue) -> Vec<(String, JValue)> {
         QueryValue::Md5 {} => {
             attributes.push(("type".to_string(), JValue::String("md5".to_string())));
         }
+        QueryValue::Certificate {
+            attribute_name: field,
+            ..
+        } => {
+            attributes.push((
+                "type".to_string(),
+                JValue::String("certificate".to_string()),
+            ));
+            attributes.push(("expr".to_string(), field.to_json()));
+        }
     };
     attributes
 }
@@ -371,6 +379,19 @@ impl ToJson for Regex {
     }
 }
 
+impl ToJson for CertificateAttributeName {
+    fn to_json(&self) -> JValue {
+        let value = match self {
+            CertificateAttributeName::Subject => "Subject",
+            CertificateAttributeName::Issuer => "Issuer",
+            CertificateAttributeName::StartDate => "Start-Date",
+            CertificateAttributeName::ExpireDate => "Expire-Date",
+            CertificateAttributeName::SerialNumber => "Serial-Number",
+        };
+        JValue::String(value.to_string())
+    }
+}
+
 impl ToJson for Predicate {
     fn to_json(&self) -> JValue {
         let mut attributes = vec![];
@@ -453,6 +474,9 @@ impl ToJson for Predicate {
             PredicateFuncValue::Exist {} => {
                 attributes.push(("type".to_string(), JValue::String("exist".to_string())));
             }
+            PredicateFuncValue::IsEmpty {} => {
+                attributes.push(("type".to_string(), JValue::String("isEmpty".to_string())));
+            }
         }
         JValue::Object(attributes)
     }
@@ -529,6 +553,22 @@ impl ToJson for FilterValue {
             FilterValue::Count => {
                 attributes.push(("type".to_string(), JValue::String("count".to_string())));
             }
+            FilterValue::DaysAfterNow => {
+                attributes.push((
+                    "type".to_string(),
+                    JValue::String("daysAfterNow".to_string()),
+                ));
+            }
+            FilterValue::DaysBeforeNow => {
+                attributes.push((
+                    "type".to_string(),
+                    JValue::String("daysBeforeNow".to_string()),
+                ));
+            }
+            FilterValue::Format { fmt, .. } => {
+                attributes.push(("type".to_string(), JValue::String("format".to_string())));
+                attributes.push(("fmt".to_string(), JValue::String(fmt.to_string())));
+            }
             FilterValue::Nth { n, .. } => {
                 attributes.push(("type".to_string(), JValue::String("nth".to_string())));
                 attributes.push(("n".to_string(), JValue::Number(n.to_string())));
@@ -568,6 +608,10 @@ impl ToJson for FilterValue {
                 attributes.push(("type".to_string(), JValue::String("split".to_string())));
                 attributes.push(("sep".to_string(), JValue::String(sep.to_string())));
             }
+            FilterValue::ToDate { fmt, .. } => {
+                attributes.push(("type".to_string(), JValue::String("toDate".to_string())));
+                attributes.push(("fmt".to_string(), JValue::String(fmt.to_string())));
+            }
             FilterValue::ToInt => {
                 attributes.push(("type".to_string(), JValue::String("toInt".to_string())));
             }
