@@ -15,7 +15,6 @@
  * limitations under the License.
  *
  */
-
 use hurl_core::ast::*;
 
 #[derive(Clone, Debug, PartialEq, Eq)]
@@ -435,6 +434,14 @@ impl Tokenizable for QueryValue {
             QueryValue::Bytes {} => tokens.push(Token::QueryType(String::from("bytes"))),
             QueryValue::Sha256 {} => tokens.push(Token::QueryType(String::from("sha256"))),
             QueryValue::Md5 {} => tokens.push(Token::QueryType(String::from("md5"))),
+            QueryValue::Certificate {
+                space0,
+                attribute_name: field,
+            } => {
+                tokens.push(Token::QueryType(String::from("certificate")));
+                tokens.append(&mut space0.tokenize());
+                tokens.append(&mut field.tokenize());
+            }
         }
         tokens
     }
@@ -471,6 +478,19 @@ impl Tokenizable for CookieAttribute {
     }
 }
 
+impl Tokenizable for CertificateAttributeName {
+    fn tokenize(&self) -> Vec<Token> {
+        let value = match self {
+            CertificateAttributeName::Subject => "Subject",
+            CertificateAttributeName::Issuer => "Issuer",
+            CertificateAttributeName::StartDate => "Start-Date",
+            CertificateAttributeName::ExpireDate => "Expire-Date",
+            CertificateAttributeName::SerialNumber => "Serial-Number",
+        };
+        vec![Token::String(value.to_string())]
+    }
+}
+
 impl Tokenizable for Predicate {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
@@ -572,6 +592,9 @@ impl Tokenizable for PredicateFuncValue {
             PredicateFuncValue::Exist {} => {
                 tokens.push(Token::PredicateType(self.name()));
             }
+            PredicateFuncValue::IsEmpty {} => {
+                tokens.push(Token::PredicateType(self.name()));
+            }
         }
         tokens
     }
@@ -1144,6 +1167,14 @@ impl Tokenizable for Filter {
     fn tokenize(&self) -> Vec<Token> {
         match self.value.clone() {
             FilterValue::Count => vec![Token::FilterType(String::from("count"))],
+            FilterValue::DaysAfterNow => vec![Token::FilterType(String::from("daysAfterNow"))],
+            FilterValue::DaysBeforeNow => vec![Token::FilterType(String::from("daysBeforeNow"))],
+            FilterValue::Format { space0, fmt } => {
+                let mut tokens: Vec<Token> = vec![Token::FilterType(String::from("format"))];
+                tokens.append(&mut space0.tokenize());
+                tokens.append(&mut fmt.tokenize());
+                tokens
+            }
             FilterValue::HtmlEscape => vec![Token::FilterType(String::from("htmlEscape"))],
             FilterValue::HtmlUnescape => {
                 vec![Token::FilterType(String::from("htmlUnescape"))]
@@ -1181,6 +1212,12 @@ impl Tokenizable for Filter {
                 tokens.append(&mut sep.tokenize());
                 tokens
             }
+            FilterValue::ToDate { space0, fmt } => {
+                let mut tokens: Vec<Token> = vec![Token::FilterType(String::from("toDate"))];
+                tokens.append(&mut space0.tokenize());
+                tokens.append(&mut fmt.tokenize());
+                tokens
+            }
             FilterValue::ToInt => vec![Token::FilterType(String::from("toInt"))],
         }
     }
